ApiClient class

Constructors

ApiClient({required SharedPreferences sharedPreferences, String baseUrl = 'https://api.jusbid.com/v1'})

Properties

dio ↔ Dio
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedPreferences → SharedPreferences
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited