Formatters class

Constructors

Formatters()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

formatCurrency(num amount) String
formatDate(DateTime date) String
formatDateRange(DateTime checkIn, DateTime checkOut) String
formatShortDate(DateTime date) String
formatTimeLeft(Duration duration) String