HotelCardData class
A minimal hotel data model used by HotelCard.
Host apps can map their own hotel entities to this model before passing them to the widget.
Constructors
Properties
-
amenities
→ List<
String> -
final
- city → String
-
final
- discountTag → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
images
→ List<
String> -
final
- name → String
-
final
- rating → double
-
final
- reviewsCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startingPrice → double
-
final
- state → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited